<?php

// determine month and year to display
$useMonth = $_GET["month"] == "" ? date("m") : $_GET["month"];
$useYear = $_GET["year"] == "" ? date("Y") : $_GET["year"];

// prep database connection
require "dbsettings.php";
$mysqli = new mysqli($host, $username, $password, $database);

// check connection
if ($mysqli->connect_errno) {
	echo "<b>Failed to connect to MySQL</b>: (" . $mysqli->connect_errno . ") " . $mysqli->connect_error;	
	return;
};

// cache device lookups
$lookupSource = $mysqli->query("SELECT deviceId, name FROM devices");
while ($row = $lookupSource->fetch_assoc()) {
    $lookup[$row['deviceId']] = $row['name'];
};
$lookupSource->close();

// get report for the required month
buildReport();

// close the connection to finish
$mysqli->close();


/**
    * Process a CSV file
*/
function buildReport() {
    global $mysqli;
	global $lookup;
	global $useMonth;
	global $useYear;
	
	$monthName = date("F", mktime(null, null, null, $useMonth));
	
	$prevMonth = $useMonth - 1;
	$prevYear = $useYear;
	if ($prevMonth <= 0) {
		$prevMonth = 12;
		$prevYear--;
	};

	$nextMonth = $useMonth + 1;
	$nextYear = $useYear;
	if ($nextMonth >= 13) {
		$nextMonth = 1;
		$nextYear++;
	};
	
	echo "<a href='report.php?month=$prevMonth&year=$prevYear'>(previous month)</a> &nbsp;&nbsp;&nbsp;";
	echo "<b>$monthName $useYear</b>";
	echo "&nbsp;&nbsp;&nbsp; <a href='report.php?month=$nextMonth&year=$nextYear'>(next month)</a>";
	echo "<br />";
	
	echo "<table border='1'>\n";

	echo "<tr style='background-color: #dddddd'>\n";
	echo "<td>Date</td>\n";
	foreach ($lookup as $key => $value) {
		if ($key > 0) {
			echo "<td>" . $value . "</td>\n";
		};
	};
	echo "</tr>\n";
	
	// collect data for this month
    $dataSource = $mysqli->query("
		select 
			dv.name, dayofmonth(d.timestamp) as day, month(d.timestamp) as month, year(d.timestamp) as year, 
			max(d.value) - min(d.value) as value 
		from 
			devicedata d, devices dv
		where 
				d.deviceid = dv.deviceid
			and 
				month(d.timestamp) = $useMonth
			and 
				year(d.timestamp) = $useYear
		group by 
			dv.name, year(d.timestamp), month(d.timestamp), dayofmonth(d.timestamp)
		order by 
			dayofmonth(d.timestamp), month(d.timestamp), year(d.timestamp)
		");
	// for value 4 (humidity sensor) we should do an Avg() instead of a max() - min().....
    while ($row = $dataSource->fetch_assoc()) {
		foreach ($lookup as $key => $value) {
			if ($value == $row['name']) {
			    $dataSort[$row['day']][$key] = $row['value'];//dataSort = Sorted Data
			};
		};
    };
    $dataSource->close();

	// add in data
	if (is_array($dataSort))
	{
		foreach ($dataSort as $key => $row) {
			echo "<tr>\n";
			echo "<td>\n";
			echo '<a href="' . "report_day.php?day=$key&month=$useMonth&year=$useYear" . '">';
			echo "$key $monthName $useYear\n</a>\n</td>\n";
			echo "<td style='text-align: center'>" . $row[1] . "</td>\n";
			echo "<td style='text-align: center'>" . $row[2] . "</td>\n";
			echo "<td style='text-align: center'>" . $row[3] . "</td>\n";
			echo "<td style='text-align: center'>" . $row[4] . "</td>\n";
			echo "</tr>\n";

			$totals[1] += $row[1];
			$totals[2] += $row[2];
			$totals[3] += $row[3];
		}
	}

	// add in totals
	if (is_array($totals))
	{
		$TotalsSumme = $totals[1] + $totals[2] + $totals[3];
		$totalsProz[1] = round($totals[1]/$TotalsSumme*100, 1);
		$totalsProz[2] = round($totals[2]/$TotalsSumme*100, 1);
		$totalsProz[3] = round($totals[3]/$TotalsSumme*100, 1);
		echo "<tr style='font-weight: bold; background-color: #dddddd'>\n";
		echo "<td>Totals: </td>\n";
		echo "<td style='text-align: center'>" . $totals[1] . "</td>\n";
		echo "<td style='text-align: center'>" . $totals[2] . "</td>\n";
		echo "<td style='text-align: center'>" . $totals[3] . "</td>\n";
		echo "<td></td>";
		echo "</tr>\n";
		
		echo "<tr style='font-weight: bold; background-color: #dddddd'>\n";
		echo "<td>Totals: </td>\n";
		echo "<td style='text-align: center'>" . $totalsProz[1] . "%</td>\n";
		echo "<td style='text-align: center'>" . $totalsProz[2] . "%</td>\n";
		echo "<td style='text-align: center'>" . $totalsProz[3] . "%</td>\n";
		echo "<td></td>";
		echo "</tr>\n";
	}

	if(
		$useMonth < date("m") && $useYear <= date("Y")
		){
		echo "</table>\n";
		echo "<hr>\n";
		echo "<h1>Gas / Heitzung</h1>\n";
		$MonatsPauschaleGas = 885/3; 
		echo "MonatsPauschaleGas : " . $MonatsPauschaleGas . " EUR<br>\n";
		echo "Mieteranteil =" . $totalsProz[1]/2 . "% + " . $totalsProz[2] . "% = ";
		$MietProz = $totalsProz[1]/2 + $totalsProz[2];
		echo $MietProz . "% <br> \n";
		$BetragMieterGas = round($MonatsPauschaleGas * $MietProz/100, 2);
		echo "BetragMieterGas : " . $BetragMieterGas . " EUR <br>\n";
		
		echo "<hr>\n<h1>Strom</h1>";
		$AlterZaehlerstand = "140";
		echo "AlterZaehlerstand : " . $AlterZaehlerstand . "KWh<br> \n";
		$NeuerZaehlerstand = "377.8";
		// Zählerstand: 414,4 kWh am 11.05.14 (einbau des m-bus zählers)
		echo "NeuerZaehlerstand : " . $NeuerZaehlerstand . "KWh<br> \n";
		$Verbrauch = $NeuerZaehlerstand - $AlterZaehlerstand;
		echo "Verbrauch diesen Monat: " . $Verbrauch . "KWh<br>\n";
		$KostenProEinheit = 0.2748;
		echo "KostenProEinheit : " . $KostenProEinheit . "EUR / KWh <br> \n";
		$BetragMieterStrom = $Verbrauch * $KostenProEinheit;
		echo "BetragMieterStrom : " . $BetragMieterStrom . "EUR <br> \n";
		
		echo "<hr>\n <h1>M&uuml;ll</h1>";
		$Muellpauschale = 10;
		echo "Muellpauschale : " .  $Muellpauschale  . "EUR <br> \n";
		echo "<hr>\n <h1>Miete, Warm</h1>";
		$MieteKalt = 49 * 7.5;
		echo "MieteKalt 49 * 7.5 : " . $MieteKalt . " EUR <br> \n";
		if(mktime(0,0,0,$useMonth, 1, $useYear) >=  mktime(0, 0, 0, 10, 1, 2014))
			$Mietreduktion = 0;
		else
			$Mietreduktion = (-1) * 1000/8;
		echo "Mietreduktion erste 12 Monate : " . $Mietreduktion . " EUR <br> \n";
		$MieteWarm = $MieteKalt + $BetragMieterStrom + $BetragMieterGas + $Mietreduktion + $Muellpauschale;
		echo "MieteWarm : " . $MieteWarm . " EUR <br> \n";
	}
}

	
	
	


?>