<?php

// determine month and year to display
$useDay = $_GET["day"] == "" ? date("d") : $_GET["day"];
$useMonth = $_GET["month"] == "" ? date("m") : $_GET["month"];
$useYear = $_GET["year"] == "" ? date("Y") : $_GET["year"];

// prep database connection
require "dbsettings.php";
$mysqli = new mysqli($host, $username, $password, $database);

// check connection
if ($mysqli->connect_errno) {
	echo "<b>Failed to connect to MySQL</b>: (" . $mysqli->connect_errno . ") " . $mysqli->connect_error;	
	return;
};

// cache device lookups
$lookupSource = $mysqli->query("SELECT deviceId, name FROM devices");
while ($row = $lookupSource->fetch_assoc()) {
    $lookup[$row['deviceId']] = $row['name'];
};
$lookupSource->close();

// get report for the required month
buildReport();

// close the connection to finish
$mysqli->close();


/**
    * Process a CSV file
*/
function buildReport() {
    global $mysqli;
	global $lookup;
	global $useDay;
	global $useMonth;
	global $useYear;
	
	$prevUNIXtime = mktime(null, null, null, $useMonth, $useDay, $useYear)-60*60*24;
	$prevDay = date("d", $prevUNIXtime);
	$prevMonth = date("m", $prevUNIXtime);
	$prevYear = date("Y", $prevUNIXtime);
	
	$nextUNIXtime = mktime(null, null, null, $useMonth, $useDay, $useYear)+60*60*24;
	$nextDay = date("d", $nextUNIXtime);
	$nextMonth = date("m", $nextUNIXtime);
	$nextYear = date("Y", $nextUNIXtime);
	
	$monthName = date("F", mktime(null, null, null, $useMonth));
	echo "<a href='report_day.php?day=$prevDay&month=$prevMonth&year=$prevYear'>(previous day)</a> &nbsp;&nbsp;&nbsp;";
	echo "<b>$useDay ";
	echo "<a href='report.php?month=$useMonth&year=$useYear'>";
	echo "$monthName $useYear</a></b>";
	echo "&nbsp;&nbsp;&nbsp; <a href='report_day.php?day=$nextDay&month=$nextMonth&year=$nextYear'>(next day)</a>";
	echo "<br />";
	
	echo "<table border='1'>\n";

	echo "<tr style='background-color: #dddddd'>\n";
	echo "<td>Time</td>\n";
	foreach ($lookup as $key => $value) {
		if ($key > 0) {
			echo "<td>" . $value . "</td>\n";
		};
	};
	echo "</tr>\n";
	
	// collect data for this month
    $dataSource = $mysqli->query("
		select 
			dv.name, 
			hour(d.timestamp)as hour,
			dayofmonth(d.timestamp) as day, 
			month(d.timestamp) as month, 
			year(d.timestamp) as year, 
			max(d.value) - min(d.value) as value 
		from 
			devicedata d, devices dv
		where 
				d.deviceid = dv.deviceid
			and	
				dayofmonth(d.timestamp) = $useDay
			and 
				month(d.timestamp) = $useMonth
			and 
				year(d.timestamp) = $useYear
		group by 
			dv.name, year(d.timestamp), month(d.timestamp), dayofmonth(d.timestamp), hour(d.timestamp)
		order by 
			hour(d.timestamp), dayofmonth(d.timestamp), month(d.timestamp), year(d.timestamp)
		");
    while ($row = $dataSource->fetch_assoc()) {
		foreach ($lookup as $key => $value) {
			if ($value == $row['name']) {
			    $dataSort[$row['hour']][$key] = $row['value'];//dataSort = Sorted Data
			};
		};
    };
    $dataSource->close();

	// add in data
	if (is_array($dataSort))
	{
		foreach ($dataSort as $key => $row) {
			echo "<tr>\n";
			$keyPlus = $key +1;
			echo "<td>$key:00-$keyPlus:00</td>\n";
			echo "<td style='text-align: center'>" . $row[1] . "</td>\n";
			echo "<td style='text-align: center'>" . $row[2] . "</td>\n";
			echo "<td style='text-align: center'>" . $row[3] . "</td>\n";
			echo "<td style='text-align: center'>" . $row[4] . "</td>\n";
			echo "</tr>\n";

			$totals[1] += $row[1];
			$totals[2] += $row[2];
			$totals[3] += $row[3];
		}
	}

	// add in totals
	if (is_array($totals))
	{
		echo "<tr style='font-weight: bold; background-color: #dddddd'>\n";
		echo "<td>Totals: </td>\n";
		echo "<td style='text-align: center'>" . $totals[1] . "</td>\n";
		echo "<td style='text-align: center'>" . $totals[2] . "</td>\n";
		echo "<td style='text-align: center'>" . $totals[3] . "</td>\n";
		echo "<td></td>";
		echo "</tr>\n";
	}
}

	
	
	


?>